@@ -11,8 +11,7 @@ class LimitNumber(CloudFormationLintRule):
     """Check if maximum Mapping limit is exceeded"""
     id = 'E7010'
     shortdesc = 'Mapping limit not exceeded'
-    description = 'Check the number of Mappings in the template is less ' \
-                  'than the upper limit'
+    description = 'Check the number of Mappings in the template is less than the upper limit'
     source_url = 'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cloudformation-limits.html'
     tags = ['mappings', 'limits']
 
